EXPORTS
	??0RA2dpBTHeadsetAudioInterface@@QAE@XZ @ 1 NONAME ; RA2dpBTHeadsetAudioInterface::RA2dpBTHeadsetAudioInterface(void)
	?BytesPlayed@RA2dpBTHeadsetAudioInterface@@QBEIXZ @ 2 NONAME ; unsigned int RA2dpBTHeadsetAudioInterface::BytesPlayed(void) const
	?CancelInitialize@RA2dpBTHeadsetAudioInterface@@QAEXXZ @ 3 NONAME ; void RA2dpBTHeadsetAudioInterface::CancelInitialize(void)
	?CancelNotifyError@RA2dpBTHeadsetAudioInterface@@QAEXXZ @ 4 NONAME ; void RA2dpBTHeadsetAudioInterface::CancelNotifyError(void)
	?CancelOpenDevice@RA2dpBTHeadsetAudioInterface@@QAEXXZ @ 5 NONAME ; void RA2dpBTHeadsetAudioInterface::CancelOpenDevice(void)
	?CancelPlayData@RA2dpBTHeadsetAudioInterface@@QAEXXZ @ 6 NONAME ; void RA2dpBTHeadsetAudioInterface::CancelPlayData(void)
	?Close@RA2dpBTHeadsetAudioInterface@@QAEXXZ @ 7 NONAME ; void RA2dpBTHeadsetAudioInterface::Close(void)
	?CloseDevice@RA2dpBTHeadsetAudioInterface@@QAEXAAVTRequestStatus@@@Z @ 8 NONAME ; void RA2dpBTHeadsetAudioInterface::CloseDevice(class TRequestStatus &)
	?Connect@RA2dpBTHeadsetAudioInterface@@QAEHXZ @ 9 NONAME ; int RA2dpBTHeadsetAudioInterface::Connect(void)
	?FlushBuffer@RA2dpBTHeadsetAudioInterface@@QAEXXZ @ 10 NONAME ; void RA2dpBTHeadsetAudioInterface::FlushBuffer(void)
	?GetSupportedChannelsL@RA2dpBTHeadsetAudioInterface@@QBEXAAV?$RArray@I@@AAW4TMMFStereoSupport@@@Z @ 11 NONAME ; void RA2dpBTHeadsetAudioInterface::GetSupportedChannelsL(class RArray<unsigned int> &, enum TMMFStereoSupport &) const
	?GetSupportedDataTypesL@RA2dpBTHeadsetAudioInterface@@QBEXAAV?$RArray@VTFourCC@@@@@Z @ 12 NONAME ; void RA2dpBTHeadsetAudioInterface::GetSupportedDataTypesL(class RArray<class TFourCC> &) const
	?GetSupportedSampleRatesL@RA2dpBTHeadsetAudioInterface@@QBEXAAV?$RArray@I@@AAV?$RArray@VTRange@@@@@Z @ 13 NONAME ; void RA2dpBTHeadsetAudioInterface::GetSupportedSampleRatesL(class RArray<unsigned int> &, class RArray<class TRange> &) const
	?Initialize@RA2dpBTHeadsetAudioInterface@@QAEXABVTBTDevAddr@@AAVTRequestStatus@@@Z @ 14 NONAME ; void RA2dpBTHeadsetAudioInterface::Initialize(class TBTDevAddr const &, class TRequestStatus &)
	?NotifyError@RA2dpBTHeadsetAudioInterface@@QAEXAAVTRequestStatus@@@Z @ 15 NONAME ; void RA2dpBTHeadsetAudioInterface::NotifyError(class TRequestStatus &)
	?OpenDevice@RA2dpBTHeadsetAudioInterface@@QAEXAAVTRequestStatus@@@Z @ 16 NONAME ; void RA2dpBTHeadsetAudioInterface::OpenDevice(class TRequestStatus &)
	?PauseBuffer@RA2dpBTHeadsetAudioInterface@@QAEXXZ @ 17 NONAME ; void RA2dpBTHeadsetAudioInterface::PauseBuffer(void)
	?PlayData@RA2dpBTHeadsetAudioInterface@@QAEXABVTDesC8@@AAVTRequestStatus@@@Z @ 18 NONAME ; void RA2dpBTHeadsetAudioInterface::PlayData(class TDesC8 const &, class TRequestStatus &)
	?ResetBytesPlayed@RA2dpBTHeadsetAudioInterface@@QAEXXZ @ 19 NONAME ; void RA2dpBTHeadsetAudioInterface::ResetBytesPlayed(void)
	?ResumePlaying@RA2dpBTHeadsetAudioInterface@@QAEXXZ @ 20 NONAME ; void RA2dpBTHeadsetAudioInterface::ResumePlaying(void)
	?SetChannels@RA2dpBTHeadsetAudioInterface@@QAEHIW4TMMFStereoSupport@@@Z @ 21 NONAME ; int RA2dpBTHeadsetAudioInterface::SetChannels(unsigned int, enum TMMFStereoSupport)
	?SetDataType@RA2dpBTHeadsetAudioInterface@@QAEHABVTFourCC@@@Z @ 22 NONAME ; int RA2dpBTHeadsetAudioInterface::SetDataType(class TFourCC const &)
	?SetSampleRate@RA2dpBTHeadsetAudioInterface@@QAEHI@Z @ 23 NONAME ; int RA2dpBTHeadsetAudioInterface::SetSampleRate(unsigned int)
	?SetVolume@RA2dpBTHeadsetAudioInterface@@QAEHI@Z @ 24 NONAME ; int RA2dpBTHeadsetAudioInterface::SetVolume(unsigned int)
	?Volume@RA2dpBTHeadsetAudioInterface@@QBEIXZ @ 25 NONAME ; unsigned int RA2dpBTHeadsetAudioInterface::Volume(void) const

